# UNMATCH
Welcome to documentation of ungreat matching of strings module. Here i will tell you how to use it.


## ungreat_match(str1,str2,mkdefolt=0.7,mismatching_chars=5)
_A function, which ungreat matching your strings and return a list with result_
* `str1` and `str2` -- strings, which you are matching
* `mkdefolt` -- coefficient, which set value of equal characters. Can get value in the range of 0 to 1.
* `mismatching_chars` -- value of mismatching characters between `str1` and `str2`
This function return a list with result and status of work, like:
`
['python', 'True']
['mismatching skills', 'False', 2]
`



You can see source code on [Github repository](https://github.com/FallenNephalem/ungreat_matching) of project.
